Crate kcr_reliablesyncs_kubeedge_io

Crate kcr_reliablesyncs_kubeedge_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the reliablesyncs.kubeedge.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

reliablesyncs.kubeedge.io/v1alpha1

  • ClusterObjectSync
  • ObjectSync

Modules

v1alpha1